@@ -7,7 +7,13 @@ __all__ = [
 __author__ = "Jeff Hui"
 __author_email__ = "jeff@jeffhui.net"
 __copyright__ = "Copyright 2013, Jeff Hui"
-__credits__ = ["Jeff Hui", "Patrice Neff", "Andrew Lee", "Will Harris"]
+__credits__ = [
+    "Jeff Hui",
+    "Patrice Neff",
+    "Andrew Lee",
+    "Will Harris",
+    "Jonas Tingeborn"
+]
 
 __license__ = "MIT"
-__version__ = "0.3.1"
+__version__ = "0.3.2"
