@@ -4,7 +4,8 @@ Scanner that relies on the MacFSEvents (OSX) library.
 This is an OS-specific implementation that eliminates the constant polling of the
 directory tree by hooking into OSX's IO events.
 """
-from base import BaseScanner
+from __future__ import absolute_import
+from .base import BaseScanner
 import os
 import fsevents
 import time
@@ -17,14 +18,13 @@ class FSEventsScanner(BaseScanner):
     def __init__(self, *args, **kwargs):
         super(FSEventsScanner, self).__init__(*args, **kwargs)
         self._observer = self._generate_observer()
-        self._stream = None
 
     def _generate_observer(self):
         observer = fsevents.Observer()
         # use file_events=True to mimic other implementations
         for path in self.paths:
-            self._stream = fsevents.Stream(self._callback, path, file_events=True)
-            observer.schedule(self._stream)
+            stream = fsevents.Stream(self._callback, path, file_events=True)
+            observer.schedule(stream)
         return observer
 
     def loop(self, sleep_time=None):
@@ -45,13 +45,15 @@ class FSEventsScanner(BaseScanner):
         #
         # So we're silently absorbing all the errors
         try:
-            from cStringIO import StringIO
+            from io import StringIO
         except:
-            from StringIO import StringIO
+            try:
+                from cStringIO import StringIO
+            except:
+                from StringIO import StringIO
         old_err, old_out = sys.stderr, sys.stdout
         sys.stderr, sys.stdout = StringIO(), StringIO()
 
-        self._observer.unschedule(self._stream)
         self._observer.stop()
 
         sys.stderr, sys.stdout = old_err, old_out
